@@ -12,6 +12,9 @@ class TokenResponse(object):
 
     @staticmethod
     def from_json(value):
+        error = value.get('error', None)
+        if error:
+            raise ValueError(value)
 
         def _normalize_key(name):
             key_parts = name.split("_")
@@ -19,6 +22,5 @@ class TokenResponse(object):
                 names = [n.title() for n in key_parts[1:]]
                 return key_parts[0] + "".join(names)
             return name
-
         json = {_normalize_key(k): v for k, v in value.items()}
         return TokenResponse(**json)
