@@ -2,46 +2,33 @@ import abc
 from time import sleep
 
 from office365.runtime.client_request_exception import ClientRequestException
+from office365.runtime.compat import is_absolute_url
+from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.queries.read_entity_query import ReadEntityQuery
 
 
 class ClientRuntimeContext(object):
 
-    def __init__(self):
-        """
-        Client runtime context
-        """
-        self._current_query = None
-        self._prev_query = None
+    def build_request(self):
+        return self.pending_request().build_request()
 
     def build_single_request(self, query):
         """
 
         :type: office365.runtime.queries.client_query.ClientQuery
         """
-        self._current_query = query
-        return self.pending_request().build_request(query)
+        return self.pending_request().build_single_request(query)
 
-    def build_request(self):
-        if self._current_query is None:
-            self._current_query = next(iter(self.pending_request()))
-        return self.build_single_request(self.current_query)
-
-    @property
-    def current_query(self):
-        """
-        :rtype: office365.runtime.queries.client_query.ClientQuery
-        """
-        return self._current_query
-
-    def execute_query_retry(self, max_retry=5, timeout_secs=5, success_callback=None, failure_callback=None):
+    def execute_query_retry(self, max_retry=5, timeout_secs=5, success_callback=None, failure_callback=None,
+                            exceptions=(ClientRequestException,)):
         """
         Executes the current set of data retrieval queries and method invocations and retries it if needed.
 
         :param int max_retry: Number of times to retry the request
         :param int timeout_secs: Seconds to wait before retrying the request.
-        :param (ClientObject)-> None success_callback:
-        :param (int)-> None failure_callback:
+        :param (office365.runtime.client_object.ClientObject)-> None success_callback:
+        :param (int, requests.exceptions.RequestException)-> None failure_callback:
+        :param exceptions: tuple of exceptions that we retry
         """
 
         for retry in range(1, max_retry):
@@ -50,13 +37,11 @@ class ClientRuntimeContext(object):
                 if callable(success_callback):
                     success_callback(self.current_query.return_type)
                 break
-            except ClientRequestException:
-                self._prev_query = self.current_query
-                self.add_query(self.current_query)
-                self._prev_query = None
+            except exceptions as e:
+                self.add_query(self.current_query, True)
                 sleep(timeout_secs)
                 if callable(failure_callback):
-                    failure_callback(retry)
+                    failure_callback(retry, e)
 
     @abc.abstractmethod
     def pending_request(self):
@@ -83,60 +68,49 @@ class ClientRuntimeContext(object):
         :type client_object: office365.runtime.client_object.ClientObject
         """
         qry = ReadEntityQuery(client_object, properties_to_retrieve)
-        self.pending_request().add_query(qry)
+        self.add_query(qry)
         return qry
 
-    def before_execute(self, action, once=True):
+    def before_execute(self, action, once=True, *args, **kwargs):
         """
         Attach an event handler which is triggered before request is submitted to server
 
-        :param (RequestOptions) -> None action:
+        :param (RequestOptions, any) -> None action:
         :param bool once:
         :return: None
         """
+
         def _process_request(request):
             if once:
                 self.pending_request().beforeExecute -= _process_request
-            action(request)
+            action(request, *args, **kwargs)
+
         self.pending_request().beforeExecute += _process_request
 
-    def before_execute_query(self, action):
-        """
-        Attach an event handler which is triggered before query is submitted to server
-
-        :param (RequestOptions) -> None action:
-        :return: None
-        """
-        def _prepare_request(request):
-            qry = self.current_query
-            action(qry)
-        self.pending_request().beforeExecute += _prepare_request
-
-    def execute_after_query(self, query, action):
+    def after_query_execute(self, query, action, *args, **kwargs):
         """
         Attach an event handler which is triggered after query is submitted to server
 
         :type query: office365.runtime.queries.client_query.ClientQuery
-        :type action: () -> None
+        :type action: (Response, *args, **kwargs) -> None
         :return: None
         """
 
-        def _process_query(resp):
-            current_query = self.current_query
-            if current_query.id == query.id:
-                self._prev_query = query
-                action()
-                self._prev_query = None
-            else:
-                self.after_execute(_process_query, True)
+        def _process_response(resp):
+            """
+            :type resp: requests.Response
+            """
+            if self.current_query.id == query.id:
+                action(*args, **kwargs)
+                self.pending_request().afterExecute -= _process_response
 
-        self.after_execute(_process_query, True)
+        self.pending_request().afterExecute += _process_response
 
-    def after_execute(self, action, once=True):
+    def after_execute(self, action, once=True, *args, **kwargs):
         """
         Attach an event handler which is triggered after request is submitted to server
 
-        :param (RequestOptions) -> None action:
+        :param (RequestOptions, *args, **kwargs) -> None action:
         :param bool once:
         :return: None
         """
@@ -144,31 +118,48 @@ class ClientRuntimeContext(object):
         def _process_response(response):
             if once:
                 self.pending_request().afterExecute -= _process_response
-            action(response)
+            action(response, *args, **kwargs)
 
         self.pending_request().afterExecute += _process_response
 
     def execute_request_direct(self, request):
         """
-        :type request: office365.runtime.http.request_options.RequestOptions
+        :type request: office365.runtime.http.request_options.RequestOptions or str
         """
-        return self.pending_request().execute_request_direct(request)
+        return self.pending_request().execute_request_direct(self._normalize_request(request))
 
     def execute_query(self):
-        for qry in self.pending_request():
-            self._current_query = qry
-            self.pending_request().execute_query(qry)
+        self.pending_request().execute_query()
 
-    def add_query(self, query):
+    def add_query(self, query, execute_first=False, set_as_current=True):
         """
-        Adds query to internal queue
-
-        :type query: ClientQuery
+        :type query: office365.runtime.queries.client_query.ClientQuery
+        :type execute_first: bool
+        :type set_as_current: bool
         """
-        self.pending_request().add_query(query, self._prev_query is not None)
-
-    def remove_query(self, query):
-        self.pending_request().remove_query(query)
+        self.pending_request().add_query(query, execute_first, set_as_current)
 
     def clear_queries(self):
         self.pending_request().queries.clear()
+
+    @property
+    def current_query(self):
+        """
+        :rtype: office365.runtime.queries.client_query.ClientQuery
+        """
+        return self.pending_request().current_query
+
+    def _normalize_request(self, request):
+        """
+        :type request: office365.runtime.http.request_options.RequestOptions or str
+        """
+        if not isinstance(request, RequestOptions):
+            request = RequestOptions(request)
+
+        if not is_absolute_url(request.url):
+            url_parts = [self.service_root_url()]
+            if not request.url.startswith("/"):
+                url_parts.append("/")
+            url_parts.append(request.url)
+            request.url = "".join(url_parts)
+        return request
