@@ -6,9 +6,9 @@ from office365.runtime.auth.user_credential import UserCredential
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
-from office365.runtime.odata.json_light_format import JsonLightFormat
-from office365.runtime.odata.odata_batch_request import ODataBatchRequest
-from office365.runtime.odata.odata_metadata_level import ODataMetadataLevel
+from office365.runtime.odata.v3.json_light_format import JsonLightFormat
+from office365.runtime.odata.v3.batch_request import ODataBatchRequest
+from office365.runtime.odata.v3.metadata_level import ODataMetadataLevel
 from office365.runtime.odata.odata_request import ODataRequest
 from office365.runtime.queries.batch_query import BatchQuery
 from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
@@ -54,8 +54,11 @@ class ClientContext(ClientRuntimeContext):
         result = Web.get_web_url_from_page_url(ctx, abs_url)
 
         def _init_context_for_web(resp):
+            """
+            :type resp: requests.Response
+            """
+            resp.raise_for_status()
             ctx._base_url = result.value
-
         ctx.after_execute(_init_context_for_web)
         return ctx
 
@@ -86,8 +89,10 @@ class ClientContext(ClientRuntimeContext):
         :type allow_ntlm: bool
         :type browser_mode: bool
         """
-        self.authentication_context.register_provider(UserCredential(username, password), allow_ntlm=allow_ntlm,
-                                                      browser_mode=browser_mode)
+        self.authentication_context.register_provider(
+            UserCredential(username, password),
+            allow_ntlm=allow_ntlm,
+            browser_mode=browser_mode)
         return self
 
     def with_credentials(self, credentials):
@@ -99,26 +104,23 @@ class ClientContext(ClientRuntimeContext):
         self.authentication_context.register_provider(credentials)
         return self
 
-    def execute_batch(self, items_per_bulk=100):
+    def execute_batch(self, items_per_batch=100):
         """
         Construct and submit a batch request
 
-        :param int items_per_bulk: Maximum to be selected for bulk operation
+        :param int items_per_batch: Maximum to be selected for bulk operation
         """
         batch_request = ODataBatchRequest(self)
 
-        all_queries = [qry for qry in self.pending_request()]
-        # batch_qry = BatchQuery(self, all_queries)
-
         def _prepare_batch_request(request):
             self.ensure_form_digest(request)
-
         batch_request.beforeExecute += _prepare_batch_request
 
-        for i in range_or_xrange(0, len(all_queries), items_per_bulk):
-            queries = all_queries[i:i + items_per_bulk]
-            batch_qry = BatchQuery(self, queries)
-            batch_request.execute_query(batch_qry)
+        all_queries = [qry for qry in self.pending_request().next_query()]
+        for i in range_or_xrange(0, len(all_queries), items_per_batch):
+            queries = all_queries[i:i + items_per_batch]
+            batch_request.add_query(BatchQuery(self, queries))
+            batch_request.execute_query()
 
     def build_single_request(self, query):
         """
@@ -145,7 +147,7 @@ class ClientContext(ClientRuntimeContext):
 
     def request_form_digest(self):
         """Request Form Digest"""
-        request = RequestOptions(self.service_root_url() + "contextInfo")
+        request = RequestOptions("contextInfo")
         request.method = HttpMethod.Post
         response = self.execute_request_direct(request)
         json = response.json()
@@ -212,4 +214,4 @@ class ClientContext(ClientRuntimeContext):
         return self._auth_context
 
     def service_root_url(self):
-        return "{0}/_api/".format(self.base_url)
+        return "{0}/_api".format(self.base_url)
