@@ -4,7 +4,7 @@ from office365.runtime.queries.service_operation_query import ServiceOperationQu
 from office365.runtime.queries.update_entity_query import UpdateEntityQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
-from office365.sharepoint.actions.create_file import create_file_query
+from office365.sharepoint.internal.create_file import create_file_query
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.changes.change_query import ChangeQuery
@@ -189,6 +189,7 @@ class Folder(BaseEntity):
 
     @property
     def storage_metrics(self):
+        """"""
         return self.properties.get("StorageMetrics",
                                    StorageMetrics(self.context, ResourcePath("StorageMetrics", self.resource_path)))
 
@@ -227,6 +228,15 @@ class Folder(BaseEntity):
         """
         return self.properties.get("Name", None)
 
+    @property
+    def is_wopi_enabled(self):
+        return self.properties.get("IsWOPIEnabled", None)
+
+    @property
+    def prog_id(self):
+        """Gets the identifier (ID) of the application in which the folder was created."""
+        return self.properties.get("ProgID", None)
+
     @property
     def unique_id(self):
         """Gets the unique ID of the folder.
@@ -254,7 +264,7 @@ class Folder(BaseEntity):
 
         :rtype: office365.sharepoint.contenttypes.content_type_id.ContentTypeId or None
         """
-        return self.properties.get("UniqueContentTypeOrder", None)
+        return self.properties.get("UniqueContentTypeOrder", ContentTypeId())
 
     @property
     def content_type_order(self):
@@ -286,16 +296,18 @@ class Folder(BaseEntity):
         """
         return self.properties.get("ServerRelativePath", SPResPath(None))
 
-    def get_property(self, name):
-        property_mapping = {
-            "ListItemAllFields": self.list_item_all_fields,
-            "ParentFolder": self.parent_folder,
-            "ServerRelativePath": self.server_relative_path
-        }
-        if name in property_mapping:
-            return property_mapping[name]
-        else:
-            return super(Folder, self).get_property(name)
+    def get_property(self, name, default_value=None):
+        if default_value is None:
+            property_mapping = {
+                "ContentTypeOrder": self.content_type_order,
+                "UniqueContentTypeOrder": self.unique_content_type_order,
+                "ListItemAllFields": self.list_item_all_fields,
+                "ParentFolder": self.parent_folder,
+                "ServerRelativePath": self.server_relative_path,
+                "StorageMetrics": self.storage_metrics
+            }
+            default_value = property_mapping.get(name, None)
+        return super(Folder, self).get_property(name, default_value)
 
     def set_property(self, name, value, persist_changes=True):
         super(Folder, self).set_property(name, value, persist_changes)
