@@ -4,7 +4,7 @@ from office365.runtime.client_value import ClientValue
 class PickerEntityInformationRequest(ClientValue):
 
     def __init__(self):
-        super().__init__()
+        super(PickerEntityInformationRequest, self).__init__()
         self.Key = None
         self.GroupId = None
         self.PrincipalType = None
