@@ -6,9 +6,11 @@ from office365.sharepoint.webs.web import Web
 class WebCollection(BaseEntityCollection):
     """Web collection"""
 
-    def __init__(self, context, resource_path=None, parent_web_url=None):
-        super(WebCollection, self).__init__(context, Web, resource_path)
-        self._parent_web_url = parent_web_url
+    def __init__(self, context, resource_path=None, parent_web=None):
+        """
+        :type parent_web: Web
+        """
+        super(WebCollection, self).__init__(context, Web, resource_path, parent_web)
 
     def add(self, web_creation_information):
         """
@@ -25,6 +27,7 @@ class WebCollection(BaseEntityCollection):
     @property
     def resource_url(self):
         url = super(WebCollection, self).resource_url
-        if self._parent_web_url is not None:
-            url = url.replace(self.context.service_root_url(), self._parent_web_url + '/_api/')
+        parent_web_url = self._parent.get_property("Url")
+        if parent_web_url is not None:
+            url = url.replace(self.context.service_root_url(), parent_web_url + '/_api/')
         return url
